.. _interacting-with-lunchable:

Interacting with Lunch Money
===================================

.. code-block:: python

   from lunchable import LunchMoney

   lunch = LunchMoney(access_token="xxxxxxx")

.. currentmodule:: lunchable

.. autoclass:: LunchMoney
    :members:
    :inherited-members:
    :autosummary:
        :toctree:
